arcgischeck: Helper function for the attached shiny function. ArcGIS...

View source: R/utils.R View source: R/supplementary_functions.R

arcgischeckR Documentation

Helper function for the attached shiny function. ArcGIS exports rastered data inverted, this function aligns the data to the usual grid.

Description

Helper function for the attached shiny function. ArcGIS exports rastered data inverted, this function aligns the data to the usual grid.

Helper function for the attached shiny function. ArcGIS exports rastered data inverted, this function aligns the data to the usual grid.

Usage

arcgischeck(data, isarcgis)

arcgischeck(data, isarcgis)

Arguments

data

2D data as used in the PALM classes

isarcgis

Logical, if data was rastered with ArcGIS set to TRUE

Value

Returns 2D data, if isarcgis == TRUE, y-axis will be reversed

Returns 2D data, if isarcgis == TRUE, y-axis will be reversed

Examples

a <- matrix(c(1:4),2,2)
b <- arcgischeck(a,TRUE)
all(a!=b)
a <- matrix(c(1:4),2,2)
b <- arcgischeck(a,TRUE)
all(a!=b)

SebaStad/rPALM documentation built on June 4, 2024, noon