| palm_global | R Documentation |
Create global parameters for static driver
Create global parameters for static driver
new()Create an R6 class that contains all global attributes needed in the static driver.
palm_global$new( title, author, institute, location, x0, y0, z0, t0, lat, lon, dx = 5 )
titleTitle of the file
authorAuthor, i.e. you
instituteYour institute
locationSite of the static driver
x0x-coordinate of the lower left point in your coordinate system
y0y-coordinate of the lower left point in your coordinate system
z0lowest z-coordinate in your domain
t0good question
latLatitude of the lower left point of your domain
lonLongitude of the lower left point of your domain
dxGrid spacing
Creates the PALM-Header Class
palm_global$new('Testglobal', 'Max Mustermann', 'Some Institute',
'Somewehere', 1, 1, 0, 0, 33,33, 10)
changeVar()palm_global$changeVar(variable, input)
changeTimeVar()palm_global$changeTimeVar(variable, input)
clone()The objects of this class are cloneable with this method.
palm_global$clone(deep = FALSE)
deepWhether to make a deep clone.
## ------------------------------------------------
## Method `palm_global$new`
## ------------------------------------------------
palm_global$new('Testglobal', 'Max Mustermann', 'Some Institute',
'Somewehere', 1, 1, 0, 0, 33,33, 10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.