| palm_ncdf_berlin | R Documentation |
Funktion die mit $new aufgerufen wird!
Funktion die mit $new aufgerufen wird!
new()palm_ncdf_berlin$new(filename, headclass, pathtofiles, oldversion = FALSE)
filenameFilename
headclassVariable of the global Class
pathtofilesPath to the Berlin data provided by the PALM4U Project
oldversionLeave at FALSE, only set to TRUE if you want to use a PALM version ~ < r2800
Creates an R6 Class
#berlin_headm <- palm_global$new(title = "GIT Example",
#author = "sest",
#institute = "IBP",
#location = "Hoki",
#x0 = 0, # only important for visualization on a map later on
#y0 = 0, # only important for visualization on a map later on
#z0 = 0,
#t0 = "2018-06-21 12:00:00 +00", # Character with Date in this format,
# might be important to have correct in later releases of PALM!
#lat = 52.502302, # important for solar radiation
#lon = 13.364862, # important for solar radiation
#dx = 5)
berlin_example <- palm_ncdf_berlin$new(filename = "berlin_static.nc",
headclass = "berlin_head",
pathtofiles = "Path/to/Berlin/data",
oldversion = FALSE)
importfiles()palm_ncdf_berlin$importfiles(lengthx, lengthy, dx, clear_overlap = FALSE)
lengthxGridpoints in x direction
lengthyGridpoints in y direction
dxGrid spacing
Imports data into PALM class for relevant PALM-4U data.
Exports a static driver with the data present in the class
exportncdf()palm_ncdf_berlin$exportncdf(Path = self$path, EPSGCode = "EPSG:25833")
PathPath where the driver is to be saved
EPSGCodeNecessary for correct display on maps. Currently only usable for few coordinate systems
Exports a static driver
Calls ggplot to plot available data in a 2D plot. Contains simple color coding for pavement, water, buildings and a distinction for small vegetation and trees. Can display the whole domain or small subareas. Missing Data is displayed as white and will be marked by the legend.
plot_area()palm_ncdf_berlin$plot_area(xleft = NULL, yleft = NULL, xl = NULL, yl = NULL)
xleftDistance to lower left corner in x direction. 1 is coordinate origin
yleftDistance to lower left corner in y direction. 1 is coordinate origin
xlLength of plot in x direction. Cannot exceed overall dimensions of domain
ylLength of plot in y direction. Cannot exceed overall dimensions of domain
Simple visualization of the simulation domain
Title
createbuilding3D()palm_ncdf_berlin$createbuilding3D(force = FALSE, orogrphy3d = FALSE)
orogrphy3dTitle
quickplot()palm_ncdf_berlin$quickplot(variable)
variableTitle
correct_surface_fraction()palm_ncdf_berlin$correct_surface_fraction()
Title
fill_areal()palm_ncdf_berlin$fill_areal( variabletofill, startx, starty, fillvalue, valuetobefilled = NULL, boundaryarea = NULL, overwrite = TRUE )
overwriteTitle
generate_lai_array()palm_ncdf_berlin$generate_lai_array( dz, fixed_tree_height = NULL, alpha = 5, beta = 3, startx = NULL, starty = NULL, lengthx = NULL, lengthy = NULL, additional_array = NULL )
additional_arrayTitle
import_data()palm_ncdf_berlin$import_data(v.file, palmtype, typeid, street = FALSE)
streetTitle
SortOverlayingdata()palm_ncdf_berlin$SortOverlayingdata(inorderof = "BPWV")
inorderofTitle
countemptyfields()palm_ncdf_berlin$countemptyfields()
Title
addsoilandsurfacefraction()palm_ncdf_berlin$addsoilandsurfacefraction(type_soil = 1)
type_soilTitle
add_lod2_variable()palm_ncdf_berlin$add_lod2_variable(name, v.data = NULL)
v.dataTitle
print()palm_ncdf_berlin$print(...)
...Title
downscale_resolution()palm_ncdf_berlin$downscale_resolution(factor)
factorTitle
cutout_static()palm_ncdf_berlin$cutout_static(startp, endp, sure = FALSE)
sureTitle
add_any2D_variable()palm_ncdf_berlin$add_any2D_variable( variablename, variable_list, print_template = FALSE )
print_templateTitle
add_R6_data()palm_ncdf_berlin$add_R6_data(data_class)
data_classTitle
add_R6_dim()palm_ncdf_berlin$add_R6_dim(dim_class)
dim_classTitle
add_soil()palm_ncdf_berlin$add_soil(type_soil = 1)
type_soilTitle
add_simple_surfacefraction()palm_ncdf_berlin$add_simple_surfacefraction()
Title
generate_lad_single_trees()palm_ncdf_berlin$generate_lad_single_trees( ext_tree_type = NULL, ext_tree_height = NULL, ext_crown_diameter = NULL, ext_tree_shape = NULL, ext_lai = NULL, overwrite_single_trees = TRUE, overwrite_existing_lad = FALSE, ... )
...Title
generate_patches_beta()palm_ncdf_berlin$generate_patches_beta( tree_array = NULL, lai, alpha = 5, beta = 3, overwrite_existing_lad = FALSE )
overwrite_existing_ladTitle
create_paraview_buildings()palm_ncdf_berlin$create_paraview_buildings()
Title
create_paraview_lad()palm_ncdf_berlin$create_paraview_lad()
Title
set_crs_from_epsg()palm_ncdf_berlin$set_crs_from_epsg(epsg_code)
epsg_codeTitle
dim()palm_ncdf_berlin$dim(...)
...clone()The objects of this class are cloneable with this method.
palm_ncdf_berlin$clone(deep = FALSE)
deepWhether to make a deep clone.
## ------------------------------------------------
## Method `palm_ncdf_berlin$new`
## ------------------------------------------------
#berlin_headm <- palm_global$new(title = "GIT Example",
#author = "sest",
#institute = "IBP",
#location = "Hoki",
#x0 = 0, # only important for visualization on a map later on
#y0 = 0, # only important for visualization on a map later on
#z0 = 0,
#t0 = "2018-06-21 12:00:00 +00", # Character with Date in this format,
# might be important to have correct in later releases of PALM!
#lat = 52.502302, # important for solar radiation
#lon = 13.364862, # important for solar radiation
#dx = 5)
berlin_example <- palm_ncdf_berlin$new(filename = "berlin_static.nc",
headclass = "berlin_head",
pathtofiles = "Path/to/Berlin/data",
oldversion = FALSE)
## ------------------------------------------------
## Method `palm_ncdf_berlin$importfiles`
## ------------------------------------------------
Exports a static driver with the data present in the class
## ------------------------------------------------
## Method `palm_ncdf_berlin$exportncdf`
## ------------------------------------------------
Calls ggplot to plot available data in a 2D plot. Contains simple color
coding for pavement, water, buildings and a distinction for small vegetation
and trees. Can display the whole domain or small subareas.
Missing Data is displayed as white and will be marked by the legend.
## ------------------------------------------------
## Method `palm_ncdf_berlin$plot_area`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$createbuilding3D`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$quickplot`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$correct_surface_fraction`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$fill_areal`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$generate_lai_array`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$import_data`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$SortOverlayingdata`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$countemptyfields`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$addsoilandsurfacefraction`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$add_lod2_variable`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$print`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$downscale_resolution`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$cutout_static`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$add_any2D_variable`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$add_R6_data`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$add_R6_dim`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$add_soil`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$add_simple_surfacefraction`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$generate_lad_single_trees`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$generate_patches_beta`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$create_paraview_buildings`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$create_paraview_lad`
## ------------------------------------------------
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin$set_crs_from_epsg`
## ------------------------------------------------
Title
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.