| palm_ncdf_berlin_old | R Documentation |
Funktion die mit $new aufgerufen wird! Title
Funktion die mit $new aufgerufen wird! Title
new()palm_ncdf_berlin_old$new(filename, headclass, pathtofiles, oldversion = FALSE)
filenameFilename
headclassVariable of the global Class
pathtofilesPath to the Berlin data provided by the PALM4U Project
oldversionLeave at FALSE, only set to TRUE if you want to use a PALM version ~ < r2800
Creates an R6 Class
#berlin_headm <- palm_global$new(title = "GIT Example",
#author = "sest",
#institute = "IBP",
#location = "Hoki",
#x0 = 0, # only important for visualization on a map later on
#y0 = 0, # only important for visualization on a map later on
#z0 = 0,
#t0 = "2018-06-21 12:00:00 +00", # Character with Date in this format,
# might be important to have correct in later releases of PALM!
#lat = 52.502302, # important for solar radiation
#lon = 13.364862, # important for solar radiation
#dx = 5)
berlin_example <- palm_ncdf_berlin$new(filename = "berlin_static.nc",
headclass = "berlin_head",
pathtofiles = "Path/to/Berlin/data",
oldversion = FALSE)
Title
importfiles()palm_ncdf_berlin_old$importfiles(lengthx, lengthy, dx)
lengthxGridpoints in x direction
lengthyGridpoints in y direction
dxGrid spacing
Imports data into PALM class for relevant PALM-4U data.
berlin_example$importfiles(lengthx = 100,
lengthy = 100,
dx = 10)
Title
Exports a static driver with the data present in the class
exportncdf()palm_ncdf_berlin_old$exportncdf(Path = self$path, EPSGCode = "EPSG:25833")
PathPath where the driver is to be saved
EPSGCodeNecessary for correct display on maps. Currently only usable for few coordinate systems
Exports a static driver
berlin_example$exportncdf(Path = "Path/to/be/saved"
EPSGCode = "EPSG:25833")
Calls ggplot to plot available data in a 2D plot. Contains simple color
coding for pavement, water, buildings and a distinction for small vegetation
and trees. Can display the whole domain or small subareas.
Missing Data is displayed as white and will be marked by the legend.
plot_area()palm_ncdf_berlin_old$plot_area(xleft, yleft, xl = 40, yl = 40)
xleftDistance to lower left corner in x direction. 1 is coordinate origin
yleftDistance to lower left corner in y direction. 1 is coordinate origin
xlLength of plot in x direction. Cannot exceed overall dimensions of domain
ylLength of plot in y direction. Cannot exceed overall dimensions of domain
Simple visualization of the simulation domain
berlin_example$plot_area(1,1,200,200)
createofficebuilding()palm_ncdf_berlin_old$createofficebuilding( start, size, height, ignorestreets = TRUE, notnew = c() )
createresidentialbuilding()palm_ncdf_berlin_old$createresidentialbuilding( start, size, height, ignorestreets = TRUE, notnew = c() )
createlod1area()palm_ncdf_berlin_old$createlod1area(start, array2d)
createbuilding3D()palm_ncdf_berlin_old$createbuilding3D(force = FALSE, orogrphy3d = FALSE)
quickplot()palm_ncdf_berlin_old$quickplot(variable)
correct_surface_fraction()palm_ncdf_berlin_old$correct_surface_fraction()
fill_areal()palm_ncdf_berlin_old$fill_areal( variabletofill, startx, starty, fillvalue, valuetobefilled = NULL, boundaryarea = NULL, overwrite = TRUE )
generate_lai_array()palm_ncdf_berlin_old$generate_lai_array( dz, fixed_tree_height = NULL, alpha = 5, beta = 3, startx = NULL, starty = NULL, lengthx = NULL, lengthy = NULL, additional_array = NULL )
import_data()palm_ncdf_berlin_old$import_data(v.file, palmtype, typeid, street = FALSE)
SortOverlayingdata()palm_ncdf_berlin_old$SortOverlayingdata(inorderof = "BPWV")
countemptyfields()palm_ncdf_berlin_old$countemptyfields()
addsoilandsurfacefraction()palm_ncdf_berlin_old$addsoilandsurfacefraction(type_soil = 1)
add_lod2_variable()palm_ncdf_berlin_old$add_lod2_variable(name, v.data = NULL)
print()palm_ncdf_berlin_old$print(...)
downscale_resolution()palm_ncdf_berlin_old$downscale_resolution(factor)
cutout_static()palm_ncdf_berlin_old$cutout_static(startp, endp, sure = FALSE)
add_any2D_variable()palm_ncdf_berlin_old$add_any2D_variable( variablename, variable_list, print_template = FALSE )
clone()The objects of this class are cloneable with this method.
palm_ncdf_berlin_old$clone(deep = FALSE)
deepWhether to make a deep clone.
## ------------------------------------------------
## Method `palm_ncdf_berlin_old$new`
## ------------------------------------------------
#berlin_headm <- palm_global$new(title = "GIT Example",
#author = "sest",
#institute = "IBP",
#location = "Hoki",
#x0 = 0, # only important for visualization on a map later on
#y0 = 0, # only important for visualization on a map later on
#z0 = 0,
#t0 = "2018-06-21 12:00:00 +00", # Character with Date in this format,
# might be important to have correct in later releases of PALM!
#lat = 52.502302, # important for solar radiation
#lon = 13.364862, # important for solar radiation
#dx = 5)
berlin_example <- palm_ncdf_berlin$new(filename = "berlin_static.nc",
headclass = "berlin_head",
pathtofiles = "Path/to/Berlin/data",
oldversion = FALSE)
Title
## ------------------------------------------------
## Method `palm_ncdf_berlin_old$importfiles`
## ------------------------------------------------
berlin_example$importfiles(lengthx = 100,
lengthy = 100,
dx = 10)
Title
Exports a static driver with the data present in the class
## ------------------------------------------------
## Method `palm_ncdf_berlin_old$exportncdf`
## ------------------------------------------------
berlin_example$exportncdf(Path = "Path/to/be/saved"
EPSGCode = "EPSG:25833")
Calls ggplot to plot available data in a 2D plot. Contains simple color
coding for pavement, water, buildings and a distinction for small vegetation
and trees. Can display the whole domain or small subareas.
Missing Data is displayed as white and will be marked by the legend.
## ------------------------------------------------
## Method `palm_ncdf_berlin_old$plot_area`
## ------------------------------------------------
berlin_example$plot_area(1,1,200,200)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.