| palm_ncdf_import | R Documentation |
R6-Class to import data from an already existing static driver
R6-Class to import data from an already existing static driver
rPALM::palm_ncdf_berlin -> palm_ncdf_import
new()palm_ncdf_import$new(newfilename, pathtofiles, oldfilename, oldversion = FALSE)
newfilenameCharacter. Filename for the future static driver
pathtofilesCharacter. Path where the old static driver lies
oldfilenameCharacter. Name of the old static driver
oldversionLogical. Only use TRUE for PALM versions <2900
The initialize/new function creates a barebones class with references to the static driver. To import the data of the static file, read_static() has to be called afterwards
import_static <- palm_ncdf_import$new("new_static_driver.nc",
"Path/to/files", "old_static_driver.nc", F)
import_static$read_static()
importfiles()palm_ncdf_import$importfiles(...)
read_static()palm_ncdf_import$read_static(...)
clone()The objects of this class are cloneable with this method.
palm_ncdf_import$clone(deep = FALSE)
deepWhether to make a deep clone.
## ------------------------------------------------
## Method `palm_ncdf_import$new`
## ------------------------------------------------
import_static <- palm_ncdf_import$new("new_static_driver.nc",
"Path/to/files", "old_static_driver.nc", F)
import_static$read_static()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.