| palm_ncdf_manual | R Documentation |
R6-Class to create a new static driver from scratch. Creates the most important data arrays depending on the grid definitions, given by the initialize/new function
R6-Class to create a new static driver from scratch. Creates the most important data arrays depending on the grid definitions, given by the initialize/new function
rPALM::palm_ncdf_berlin -> palm_ncdf_manual
new()palm_ncdf_manual$new( nx, ny, dx, headclass, oldversion = FALSE, gui.arcgis = FALSE )
nxNumerical. Grid points in x direction
nyNumerical. Grid points in y direction
dxNumerical. Grid spacing
headclassR6-Class.
oldversionLogical. Only use TRUE for PALM versions <2900
gui.arcgisLogical. Set to TRUE, when you want to import rastered files created by ARCGIS.
The initialize/new functions creates a R6 class, where most important arrays (vegetation_type, buildings_2d, etc) are initialized with fill values.
manual_static <- palm_ncdf_manual$new(200,200,10, palm_headclass, FALSE, FALSE)
importfiles()palm_ncdf_manual$importfiles(...)
importbuildings_DUMMY()palm_ncdf_manual$importbuildings_DUMMY(filepath)
getBuildingID()palm_ncdf_manual$getBuildingID(filepath, trustfile = FALSE)
clone()The objects of this class are cloneable with this method.
palm_ncdf_manual$clone(deep = FALSE)
deepWhether to make a deep clone.
## ------------------------------------------------
## Method `palm_ncdf_manual$new`
## ------------------------------------------------
manual_static <- palm_ncdf_manual$new(200,200,10, palm_headclass, FALSE, FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.