| palm_ncdf_shiny | R Documentation |
R6 Class to create a static driver for the shiny app. The domain is defined via the topography file, other data arrays have to be defined later.
R6 Class to create a static driver for the shiny app. The domain is defined via the topography file, other data arrays have to be defined later.
rPALM::palm_ncdf_berlin -> palm_ncdf_shiny
new()palm_ncdf_shiny$new( topofile, headclass, oldversion = FALSE, gui.arcgis = FALSE )
topofileLink to a rastered ncfile with topography. May not conatin fill values!
headclassR6-Class.
oldversionLogical. Only use TRUE for PALM versions <2900
gui.arcgisLogical. Set to TRUE, when you want to import rastered files created by ARCGIS.
The initialize/new functions creates a R6 class that only contains the array "zt". Other information has to be loaded via import_files()
shiny_static <- palm_ncdf_shiny$new("Path/to/topfile.nc", palm_headclass, FALSE, FALSE)
importfiles()palm_ncdf_shiny$importfiles(...)
importbuildings_DUMMY()palm_ncdf_shiny$importbuildings_DUMMY(filepath)
getBuildingID()palm_ncdf_shiny$getBuildingID(filepath, trustfile = FALSE)
clone()The objects of this class are cloneable with this method.
palm_ncdf_shiny$clone(deep = FALSE)
deepWhether to make a deep clone.
## ------------------------------------------------
## Method `palm_ncdf_shiny$new`
## ------------------------------------------------
shiny_static <- palm_ncdf_shiny$new("Path/to/topfile.nc", palm_headclass, FALSE, FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.