View source: R/utils.R View source: R/supplementary_functions.R
| arcgischeck | R Documentation |
Helper function for the attached shiny function. ArcGIS exports rastered data inverted, this function aligns the data to the usual grid.
Helper function for the attached shiny function. ArcGIS exports rastered data inverted, this function aligns the data to the usual grid.
arcgischeck(data, isarcgis)
arcgischeck(data, isarcgis)
data |
2D data as used in the PALM classes |
isarcgis |
Logical, if data was rastered with ArcGIS set to TRUE |
Returns 2D data, if isarcgis == TRUE, y-axis will be reversed
Returns 2D data, if isarcgis == TRUE, y-axis will be reversed
a <- matrix(c(1:4),2,2)
b <- arcgischeck(a,TRUE)
all(a!=b)
a <- matrix(c(1:4),2,2)
b <- arcgischeck(a,TRUE)
all(a!=b)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.